diff src/status.h @ 12595:3169cd6727ad

[gaim-migrate @ 14925] I've been meaning to spend the time to commit these changes separately, but it's been a couple days without me finding the time... 1. Allow the creation of GaimStatusTypes by passing NULL for the name and/or id. The core uses the default name and/or id. This eliminates quite a bit of duplication in the prpls. 2. Make statuses more consistent. For example, in some prpls, "Busy" was descended from the UNAVAILABLE primitive and on others it was a case of AWAY. Another example... "On Vacation" is definitely an EXTENDED_AWAY not an AWAY. 3. Rename some pixmaps to elminate some special cases. The names of the pixmaps should now match the primitive default IDs. 4. Rename the HIDDEN primitive to INVISIBLE, since we seem to be using that term everywhere. In conjunction with #1, more duplication was eliminated. 5. Add a MOBILE status primitive. It's not used now. It'll be needed in the (hopefully not-too-distant) future, so I'm planning ahead. 6. Shrink the status select for small blist folks. Now if someone can get rid of that stupid extra padding, we'll be set (well, after we deal with imhtml space issues). I've fought with this for many many hours over several days and I can't get it. It's clear that the combo box is requesting more space than is really necessary, but I don't know why. This is really my first go at anything significant status-related. Everyone should check their favorite prpls carefully to make sure I didn't break anything. committer: Tailor Script <tailor@pidgin.im>
author Richard Laager <rlaager@wiktel.com>
date Wed, 21 Dec 2005 08:24:17 +0000
parents 74e33b6d8d74
children 0f64896eab01
line wrap: on
line diff
--- a/src/status.h	Wed Dec 21 07:59:45 2005 +0000
+++ b/src/status.h	Wed Dec 21 08:24:17 2005 +0000
@@ -100,9 +100,10 @@
 	GAIM_STATUS_OFFLINE,
 	GAIM_STATUS_AVAILABLE,
 	GAIM_STATUS_UNAVAILABLE,
-	GAIM_STATUS_HIDDEN,
+	GAIM_STATUS_INVISIBLE,
 	GAIM_STATUS_AWAY,
 	GAIM_STATUS_EXTENDED_AWAY,
+	GAIM_STATUS_MOBILE,
 	GAIM_STATUS_NUM_PRIMITIVES
 
 } GaimStatusPrimitive;
@@ -113,7 +114,7 @@
 #include "value.h"
 
 /**************************************************************************/
-/** @name GaimStatusPrimtive API                                          */
+/** @name GaimStatusPrimitive API                                         */
 /**************************************************************************/
 /*@{*/
 
@@ -159,8 +160,10 @@
  * Creates a new status type.
  *
  * @param primitive     The primitive status type.
- * @param id            The ID of the status type.
- * @param name          The name presented to the user.
+ * @param id            The ID of the status type, or @c NULL to use the id of
+ *                      the primitive status type.
+ * @param name          The name presented to the user, or @c NULL to use the
+ *                      name of the primitive status type.
  * @param saveable      TRUE if the information set for this status by the
  *                      user can be saved for future sessions.
  * @param user_settable TRUE if this is a status the user can manually set.
@@ -180,8 +183,10 @@
  * savable and not independent).
  *
  * @param primitive     The primitive status type.
- * @param id            The ID of the status type.
- * @param name          The name presented to the user.
+ * @param id            The ID of the status type, or @c NULL to use the id of
+ *                      the primitive status type.
+ * @param name          The name presented to the user, or @c NULL to use the
+ *                      name of the primitive status type.
  * @param user_settable TRUE if this is a status the user can manually set.
  *
  * @return A new status type.
@@ -194,8 +199,10 @@
  * Creates a new status type with attributes.
  *
  * @param primitive     The primitive status type.
- * @param id            The ID of the status type.
- * @param name          The name presented to the user.
+ * @param id            The ID of the status type, or @c NULL to use the id of
+ *                      the primitive status type.
+ * @param name          The name presented to the user, or @c NULL to use the
+ *                      name of the primitive status type.
  * @param saveable      TRUE if the information set for this status by the
  *                      user can be saved for future sessions.
  * @param user_settable TRUE if this is a status the user can manually set.
@@ -343,7 +350,7 @@
 /**
  * Returns whether or not a status type is available.
  *
  * Available status types are online and possibly hidden, but not away.
  *
  * @param status_type The status type.
  *
@@ -608,7 +615,7 @@
 /**
  * Returns whether or not a status is available.
  *
  * Available statuses are online and possibly hidden, but not away or idle.
  *
  * This is a convenience method for
  * gaim_status_type_is_available(gaim_status_get_type(status)).
@@ -898,7 +905,7 @@
 /**
  * Returns whether or not a presence is available.
  *
  * Available presences are online and possibly hidden, but not away or idle.
  *
  * @param presence The presence.
  *
@@ -343,7 +350,7 @@
  * Returns whether or not a status type is available.
  *
- * Available status types are online and possibly hidden, but not away.
+ * Available status types are online and possibly invisible, but not away.
  *
  * @param status_type The status type.
@@ -608,7 +615,7 @@
  * Returns whether or not a status is available.
  *
- * Available statuses are online and possibly hidden, but not away or idle.
+ * Available statuses are online and possibly invisible, but not away or idle.
  *
  * This is a convenience method for
@@ -898,7 +905,7 @@
  * Returns whether or not a presence is available.
  *
- * Available presences are online and possibly hidden, but not away or idle.
+ * Available presences are online and possibly invisible, but not away or idle.
  *
  * @param presence The presence.